@@ -1,4 +1,3 @@
-
 system.file2 = function(..., package = "GRANBase") {
     ret = tryCatch(system.file(..., package = package), error = function(e) e)
 
@@ -21,8 +20,8 @@ system.file2 = function(..., package = "GRANBase") {
 #' Utility function which writes gran logs
 #' @param pkg The name of the package the log is about
 #' @param msg The log message, collapsed if length>1
-#' @param type "full", "error", or "both" indicating which log(s) the message
-#' should be written to
+#' @param type "full", "error", "warn", or "both" indicating which
+#' log(s) the message should be written to
 #' @param logfile The location of the full log file to write/append to
 #' @param errfile the location of the error log file to write/append to
 #' @param pkglog character. The package-specific log file to write to if
@@ -30,18 +29,17 @@ system.file2 = function(..., package = "GRANBase") {
 #' @note This function is not intended for direct use by the end user.
 #' @export
 writeGRANLog = function(pkg, msg, type = "full", logfile,
-                      errfile, pkglog = NULL)
+                        errfile, pkglog = NULL)
 {
-
-    dt = date()
-
-    if(type == "error")
-    {
+    if(type == "error") {
         targ = errfile
         err = " ERROR "
     } else if (type == "both") {
         targ = c(logfile, errfile)
         err = " ERROR "
+    } else if (type == "warn") {
+        targ = c(logfile, errfile)
+        err = " WARNING "
     } else {
         targ = logfile
         err = character()
@@ -49,9 +47,13 @@ writeGRANLog = function(pkg, msg, type = "full", logfile,
     if(!is.null(pkg) && !is.na(pkg))
         targ = c(targ, pkglog)
 
-    fullmsg = paste("\n",err, "pkg:", pkg, "(", dt, ") - ",
+    fullmsg <- paste("\n", err, "pkg:", pkg, "(", date(), ") - ",
         paste(paste0("\t",msg), collapse="\n\t"))
-    sapply(targ, function(x) cat(fullmsg, append=TRUE, file=x))
+    sapply(targ, function(x) {
+      if (!file.exists(x))
+          file.create(x)
+      cat(fullmsg, append = TRUE, file = x)
+    })
 }
 
 getPkgNames = function(path)
@@ -133,18 +135,6 @@ install.packages2 = function(pkgs, repos, lib,  ..., param = SwitchrParam(),
     ##end up in both locations!
     ##install.packages(pkgs, ..., keep_outputs=outdir)
     avail = available.packages(contrib.url(repos, type = "source"))
-    ## args = list(pkgs = pkgs, repos = repos, lib = lib, ...,
-    ##     INSTALL_opts = sprintf("-l %s", lib),
-    ##     keep_outputs = outdir)
-
-
-    ## tmpfile = tempfile(fileext=".rda")
-    ## save(args, outdir, file =tmpfile)
-    ## code = sprintf("load('%s'); wd = setwd(outdir);on.exit(setwd(wd)); .libPaths(args$lib); do.call(install.packages, args)", tmpfile)
-    ## codefile = tempfile(pattern="instcode", fileext=".R")
-    ## cat(code, file= codefile)
-    ## cmd = paste0("R_LIBS_SITE=", lib, " R_LIBS_USER=",lib, " R", " --no-save <", codefile)
-    ## system_w_init(cmd, param = param)
     install.packages(pkgs = pkgs, repos = repos,
                          INSTALL_opts = sprintf("-l %s", lib), lib = lib,
                          ..., keep_outputs=TRUE)
@@ -205,9 +195,10 @@ trim_PACKAGES = function(dir) {
     pkgsdf = as.data.frame(pkgs)
     if("File" %in% names(pkgsdf))
         fils = pkgsdf$Files
-    else
-
-        fils = file.path(dir, paste0(pkgsdf$Package, "_", pkgsdf$Version, builtPkgExt()))
+    else {
+        fils = file.path(dir, paste0(pkgsdf$Package, "_",
+                                     pkgsdf$Version, builtPkgExt()))
+    }
     missing = !file.exists(fils)
     pkgsdf = pkgsdf[!missing,]
     out <- file(file.path(dir, "PACKAGES"), "wt")
